==> DI-engine-0.3.0.tar.gz: DI-engine-0.3.0/dizoo/atari/config/serial/pong/pong_iqn_config.py <==
from copy import deepcopy
from ding.entry import serial_pipeline
from easydict import EasyDict

pong_iqn_config = dict(
    env=dict(
        collector_env_num=8,
        evaluator_env_num=8,
        n_evaluator_episode=8,
        stop_value=20,
        env_id='PongNoFrameskip-v4',
        frame_stack=4,
        manager=dict(shared_memory=False, )
    ),
    policy=dict(
        cuda=True,
        priority=False,
        model=dict(
            obs_shape=[4, 84, 84],
            action_shape=6,
            encoder_hidden_size_list=[128, 128, 512],
            num_quantiles=32,
        ),
        nstep=3,
        discount_factor=0.99,
        kappa=1.0,
        learn=dict(
            update_per_collect=10,
            batch_size=32,
            learning_rate=0.0001,
            target_update_freq=500,
        ),
        collect=dict(n_sample=100, ),
        eval=dict(evaluator=dict(eval_freq=4000, )),
        other=dict(
            eps=dict(
                type='exp',
                start=1.,
                end=0.05,
                decay=250000,
            ),
            replay_buffer=dict(replay_buffer_size=100000, ),
        ),
    ),
)
pong_iqn_config = EasyDict(pong_iqn_config)
main_config = pong_iqn_config
pong_iqn_create_config = dict(
    env=dict(
        type='atari',
        import_names=['dizoo.atari.envs.atari_env'],
    ),
    env_manager=dict(type='subprocess'),
    policy=dict(type='iqn'),
)
pong_iqn_create_config = EasyDict(pong_iqn_create_config)
create_config = pong_iqn_create_config

if __name__ == '__main__':
    serial_pipeline((main_config, create_config), seed=0)

==> DI-engine-0.4.0.tar.gz: DI-engine-0.4.0/dizoo/atari/config/serial/pong/pong_iqn_config.py <==
from easydict import EasyDict

pong_iqn_config = dict(
    exp_name='pong_iqn_seed0',
    env=dict(
        collector_env_num=8,
        evaluator_env_num=8,
        n_evaluator_episode=8,
        stop_value=20,
        env_id='PongNoFrameskip-v4',
        frame_stack=4,
    ),
    policy=dict(
        cuda=True,
        priority=False,
        model=dict(
            obs_shape=[4, 84, 84],
            action_shape=6,
            encoder_hidden_size_list=[128, 128, 512],
            num_quantiles=32,
        ),
        nstep=3,
        discount_factor=0.99,
        kappa=1.0,
        learn=dict(
            update_per_collect=10,
            batch_size=32,
            learning_rate=0.0001,
            target_update_freq=500,
        ),
        collect=dict(n_sample=100, ),
        eval=dict(evaluator=dict(eval_freq=4000, )),
        other=dict(
            eps=dict(
                type='exp',
                start=1.,
                end=0.05,
                decay=250000,
            ),
            replay_buffer=dict(replay_buffer_size=100000, ),
        ),
    ),
)
pong_iqn_config = EasyDict(pong_iqn_config)
main_config = pong_iqn_config

pong_iqn_create_config = dict(
    env=dict(
        type='atari',
        import_names=['dizoo.atari.envs.atari_env'],
    ),
    env_manager=dict(type='subprocess'),
    policy=dict(type='iqn'),
)
pong_iqn_create_config = EasyDict(pong_iqn_create_config)
create_config = pong_iqn_create_config

if __name__ == '__main__':
    # or you can enter `ding -m serial -c pong_iqn_config.py -s 0`
    from ding.entry import serial_pipeline
    serial_pipeline((main_config, create_config), seed=0)
